@@ -1,6 +1,7 @@
-#!/usr/local/bin/perl -w
+#!/usr/bin/perl -w
 
 use strict;
+use warnings;
 use Getopt::Long;
 use Pod::Usage;
 use FindBin;
@@ -43,11 +44,10 @@ Run a Catalyst action from the command line.
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri@oook.de>
+Maintained by the Catalyst Core Team.
 
 =head1 COPYRIGHT
 
-Copyright 2004 Sebastian Riedel. All rights reserved.
-
 This library is free software, you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
